@@ -11,19 +11,18 @@ import sys
 import mido
 from mido import MidiFile
 
+filename = sys.argv[1]
 if len(sys.argv) == 3:
-    port_name = sys.argv[2]
+    portname = sys.argv[2]
 else:
-    port_name = None
+    portname = None
 
-with mido.open_output(port_name) as output:
+with mido.open_output(portname) as output:
     try:
-        print(output)
-        with MidiFile(sys.argv[1]) as midi_file:
-            for message in midi_file.play():
-                print(message)
-                output.send(message)
+        for message in MidiFile(filename).play():
+            print(message)
+            output.send(message)
+
     except KeyboardInterrupt:
         print()
         output.reset()
-
