@@ -9,6 +9,7 @@ Creating messages:
 
     Message(type, **parameters) -- create a new message
     MetaMessage(type, **parameters) -- create a new meta message
+    UnknownMetaMessage(type_byte, data=None, time=0)
 
 Ports:
 
@@ -92,23 +93,25 @@ from __future__ import absolute_import
 import os
 from .backends.backend import Backend
 from . import ports, sockets
-from .messages import Message
-from .messages import parse_string, parse_string_stream, format_as_string
+from .messages import (Message, parse_string, parse_string_stream,
+                       format_as_string, MIN_PITCHWHEEL, MAX_PITCHWHEEL,
+                       MIN_SONGPOS, MAX_SONGPOS)
 from .parser import Parser, parse, parse_all
-from .midifiles import MidiFile, MidiTrack, merge_tracks
-from .midifiles import MetaMessage, bpm2tempo, tempo2bpm
+from .midifiles import (MidiFile, MidiTrack, merge_tracks,
+                        MetaMessage, UnknownMetaMessage,
+                        bpm2tempo, tempo2bpm, tick2second, second2tick)
 from .syx import read_syx_file, write_syx_file
+from .version import version_info, version as __version__
 
 __author__ = 'Ole Martin Bjorndalen'
 __email__ = 'ombdalen@gmail.com'
 __url__ = 'https://mido.readthedocs.io/'
 __license__ = 'MIT'
-__version__ = '1.1.18'
 
 # Prevent splat import.
 __all__ = []
 
-def set_backend(name=None):
+def set_backend(name=None, load=False):
     """Set current backend.
 
     name can be a module name like 'mido.backends.rtmidi' or
@@ -125,7 +128,7 @@ def set_backend(name=None):
     if isinstance(name, Backend):
         backend = name
     else:
-        backend = Backend(name, load=False, use_environ=True)
+        backend = Backend(name, load=load, use_environ=True)
     glob['backend'] = backend
 
     for name in dir(backend):
