@@ -7,10 +7,7 @@ available in the toplevel module.
 PortMidi documentation:
 http://portmedia.sourceforge.net/portmidi/doxygen/
 """
-import time
 import threading
-from ..parser import Parser
-from ..messages import Message
 from ..ports import BaseInput, BaseOutput, sleep
 from . import portmidi_init as pm
 
@@ -38,8 +35,6 @@ def _check_error(return_value):
     
     
 def _get_device(device_id):
-    device = {}
-    
     info_pointer = pm.lib.Pm_GetDeviceInfo(device_id)
     if not info_pointer:
         raise IOError('PortMidi device with id={} not found'.format(
@@ -110,23 +105,21 @@ class PortCommon(object):
 
         self._stream = pm.PortMidiStreamPtr()
 
-        opening_input = hasattr(self, 'receive')
-
         if self.name is None:
-            device = _get_default_device(opening_input)
+            device = _get_default_device(self.is_input)
             self.name = device['name']
         else:
-            device = _get_named_device(self.name, opening_input)
+            device = _get_named_device(self.name, self.is_output)
 
         if device['opened']:
-            if opening_input:
+            if self.is_input:
                 devtype = 'input'
             else:
                 devtype = 'output'
             raise IOError('{} port {!r} is already open'.format(devtype,
                                                                 self.name))
         
-        if opening_input:
+        if self.is_input:
             _check_error(pm.lib.Pm_OpenInput(
                          pm.byref(self._stream),
                          device['id'],  # Input device
@@ -150,7 +143,7 @@ class PortCommon(object):
         self.closed = False
         _state['port_count'] += 1
  
-        if opening_input:
+        if self.is_input:
             self._thread = None
             self.callback = kwargs.get('callback')
 
