@@ -4,14 +4,15 @@ Low-level wrapper for PortMidi library
 Copied straight from Grant Yoshida's portmidizero, with slight
 modifications.
 """
-
 import sys
-import array
-from ctypes import *
+from ctypes import (CDLL, CFUNCTYPE, POINTER, Structure, c_char_p,
+                    c_int, c_long, c_uint, c_void_p, cast,
+                    create_string_buffer, byref)
+import ctypes.util
 
 dll_name = ''
 if sys.platform == 'darwin':
-    dll_name = 'libportmidi.dylib'
+    dll_name = ctypes.util.find_library('libportmidi.dylib')
 elif sys.platform in ('win32', 'cygwin'):
     dll_name = 'portmidi.dll'
 else:
