@@ -1,18 +1,10 @@
 """
 Useful tools for working with ports
-
-Module content:
-
-    multi_receive -- receive messages from multiple ports
-    IOPort -- combined input / output port. Wraps around to normal ports
-    MessageBuffer -- pseudo-port that stores messages in a deque
 """
-
 from __future__ import unicode_literals
 import threading
 import time
 import random
-from collections import deque
 from .parser import Parser
 from .messages import Message
 
@@ -41,14 +33,57 @@ def get_sleep_time():
     return _sleep_time
 
 
+def reset_messages():
+    """Yield "All Notes Off" and "Reset All Controllers" for all channels"""
+    ALL_NOTES_OFF = 123
+    RESET_ALL_CONTROLLERS = 121
+    for channel in range(16):
+        for control in [ALL_NOTES_OFF, RESET_ALL_CONTROLLERS]:
+            yield Message('control_change', channel=channel, control=control)
+
+
+def panic_messages():
+    """Yield "All Sounds Off" for all channels.
+
+    This will mute all sounding notes regardless of
+    envelopes. Useful when notes are hanging and nothing else
+    helps.
+    """
+    ALL_SOUNDS_OFF = 120
+    for channel in range(16):
+        yield Message('control_change',
+                      channel=channel, control=ALL_SOUNDS_OFF)
+
+
+
+class DummyLock(object):
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *_):
+        return False
+
+
 class BasePort(object):
     """
     Abstract base class for Input and Output ports.
     """
 
+    is_input = False
+    is_output = False
+    _locking = True
+
     def __init__(self, name=None, **kwargs):
+        if hasattr(self, 'closed'):
+            # __init__() called twice (from BaseInput and BaseOutput).
+            # This stops _open() from being called twice.
+            return
+
         self.name = name
-        self._lock = threading.RLock()
+        if self._locking:
+            self._lock = threading.RLock()
+        else:
+            self._lock = DummyLock()
         self.closed = True
         self._open(**kwargs)
         self.closed = False
@@ -93,12 +128,12 @@ class BasePort(object):
         else:
             state = 'open'
 
-        capabilities = (hasattr(self, 'receive'), hasattr(self, 'send'))
+        capabilities = self.is_input, self.is_output
         port_type = {
             (True, False): 'input',
             (False, True): 'output',
-            (True, True): 'I/O',
-            (False, False): 'mute',
+            (True, True): 'I/O port',
+            (False, False): 'mute port',
             }[capabilities]
 
         name = self.name or ''
@@ -118,6 +153,8 @@ class BaseInput(BasePort):
     Subclass and override _receive() to create a new input port type.
     (See portmidi.py for an example of how to do this.)
     """
+    is_input = True
+
     def __init__(self, name='', **kwargs):
         """Create an input port.
 
@@ -136,37 +173,14 @@ class BaseInput(BasePort):
     def _receive(self, block=True):
         pass
 
-    def pending(self):
-        """Return how many messages are ready to be received.
-
-        *Note*: This is kept around for backward compatibility.  It's
-        better to use iter_pending() to iterate over pending messages.
-
-        This will read data from the device and put it in the
-        parser. I will then return the number of messages available to
-        be received.
-
-        The value will not be reliable when receiving messages in
-        multiple threads.
-
-        If this is called on a closed port it will work as normal
-        except it won't try to read from the device.
-        """
-        with self._lock:
-            if not self.closed:
-                self._check_callback()
-                self._receive(block=False)
-
-            return len(self._messages)
-
     def iter_pending(self):
         """Iterate through pending messages."""
         while True:
-            message = self.poll()
-            if message is None:
+            msg = self.poll()
+            if msg is None:
                 return
             else:
-                yield message
+                yield msg
 
     def receive(self, block=True):
         """Return the next message.
@@ -181,6 +195,9 @@ class BaseInput(BasePort):
         IOError will be raised. Todo: this seems a bit inconsistent. Should
         different errors be raised? What's most useful here?
         """
+        if not self.is_input:
+            raise ValueError('Not an input port')
+
         self._check_callback()
 
         # If there is a message pending, return it right away.
@@ -196,21 +213,9 @@ class BaseInput(BasePort):
 
         while True:
             with self._lock:
-                # In the future we should allow self._receive() to
-                # return a message.  This would make the API more
-                # consistent and also make it easier to implement
-                # thread safe ports since self._messages is no longer
-                # required.
-                #
-                # This can only be done if pending() is removed, since
-                # it calls self._receive().
-                #
-                # A commented out implementation is provided below.
-                self._receive(block=block)
-                # msg = self._receive(block=block)
-                # if msg:
-                #     return msg
-                # # (else check self._messages as before.)
+                msg = self._receive(block=block)
+                if msg:
+                    return msg
 
                 if self._messages:
                     return self._messages.popleft()
@@ -253,6 +258,7 @@ class BaseOutput(BasePort):
     Subclass and override _send() to create a new port type.  (See
     portmidi.py for how to do this.)
     """
+    is_output = True
 
     def __init__(self, name='', autoreset=False, **kwargs):
         """Create an output port
@@ -263,36 +269,32 @@ class BaseOutput(BasePort):
         BasePort.__init__(self, name, **kwargs)
         self.autoreset = autoreset
  
-    def _send(self, message):
+    def _send(self, msg):
         pass
 
-    def send(self, message):
+    def send(self, msg):
         """Send a message on the port.
 
         A copy of the message will be sent, so you can safely modify
         the original message without any unexpected consequences.
         """
-        if not isinstance(message, Message):
+        if not self.is_output:
+            raise ValueError('Not an output port')
+        elif not isinstance(msg, Message):
             raise TypeError('argument to send() must be a Message')
         elif self.closed:
             raise ValueError('send() called on closed port')
 
         with self._lock:
-            self._send(message.copy())
+            self._send(msg.copy())
 
     def reset(self):
-        """Send "All Notes Off" and "Reset All Controllers" on all channels
-        """
+        """Send "All Notes Off" and "Reset All Controllers" on all channels"""
         if self.closed:
             return
 
-        ALL_NOTES_OFF = 123
-        RESET_ALL_CONTROLLERS = 121
-        for channel in range(16):
-            for control in [ALL_NOTES_OFF, RESET_ALL_CONTROLLERS]:
-                self.send(Message('control_change',
-                                  channel=channel,
-                                  control=control))
+        for msg in reset_messages():
+            self.send(msg)
 
     def panic(self):
         """Send "All Sounds Off" on all channels.
@@ -304,11 +306,8 @@ class BaseOutput(BasePort):
         if self.closed:
             return
 
-        ALL_SOUNDS_OFF = 120
-        for channel in range(16):
-            self.send(Message('control_change',
-                              channel=channel,
-                              control=ALL_SOUNDS_OFF))
+        for msg in panic_messages():
+            self.send(msg)
 
 
 class BaseIOPort(BaseInput, BaseOutput):
@@ -329,6 +328,8 @@ class IOPort(BaseIOPort):
     is forwarded to the appropriate port.
     """
 
+    _locking = False
+
     def __init__(self, input, output):
         self.input = input
         self.output = output
@@ -344,10 +345,10 @@ class IOPort(BaseIOPort):
         self.output.close()
 
     def _send(self, message):
-        self.output._send(message)
+        self.output.send(message)
 
     def _receive(self, block=True):
-        return self.input._receive()
+        return self.input.receive()
 
 
 class EchoPort(BaseIOPort):
@@ -413,3 +414,9 @@ def multi_iter_pending(ports, yield_ports=False):
     The function is kept around for backwards compatability.
     """
     return multi_receive(ports, yield_ports=yield_ports, block=False)
+
+
+def multi_send(ports, msg):
+    """Send message on all ports."""
+    for port in ports:
+        port.send(msg)
