@@ -1,15 +1,12 @@
 """
 MIDI over TCP/IP.
 """
-import sys
-import time
 import socket
 import select
-from collections import deque
 from .parser import Parser
-from .ports import MultiPort, BaseIOPort, multi_iter_pending, sleep
+from .ports import MultiPort, BaseIOPort
+from .py2 import PY2
 
-PY2 = (sys.version_info.major == 2)
 
 def _is_readable(socket):
     """Return True if there is data to be read on the socket."""
@@ -77,7 +74,7 @@ class PortServer(MultiPort):
 
 class SocketPort(BaseIOPort):
     def __init__(self, host, portno, conn=None):
-        self.name = format_address(host, portno)
+        BaseIOPort.__init__(self, name=format_address(host, portno))
         self.closed = False
         self._parser = Parser()
         self._messages = self._parser.messages
