@@ -3,27 +3,19 @@ Read and write SYX file format
 """
 from __future__ import print_function
 import re
-import string
-import binascii
-from .messages import Message
-from .parser import Parser, parse_all
+from .parser import Parser
 
-_HEXDIGITS = set(string.hexdigits.encode('ascii'))
 
 def read_syx_file(filename):
     """Read sysex messages from SYX file.
 
     Returns a list of sysex messages.
-    
+
     This handles both the text (hexadecimal) and binary
     formats. Messages other than sysex will be ignored. Raises
     ValueError if file is plain text and byte is not a 2-digit hex
     number.
     """
-    def raise_value_error():
-        raise ValueError('{!r} line {}: invalid hex byte {!r}'.format(
-            filename, lineno, byte))
-
     with open(filename, 'rb') as infile:
         data = infile.read()
 
@@ -31,17 +23,19 @@ def read_syx_file(filename):
         # Empty file.
         return []
 
+    parser = Parser()
+
     # data[0] will give a byte string in Python 2 and an integer in
     # Python 3.
     if data[0] in (b'\xf0', 240):
-        # Binary.
-        return parse_all(data)
+        # Binary format.
+        parser.feed(data)
     else:
-        # Hex.
-        # We're decoding as latin1 to avoid decoding errors.
-        data = bytearray.fromhex(data.decode('latin1'))
+        text = data.decode('latin1')
+        data = bytearray.fromhex(re.sub(r'\s', ' ', text))
+        parser.feed(data)
 
-        return [msg for msg in Parser(data) if msg.type == 'sysex']
+    return [msg for msg in parser if msg.type == 'sysex']
 
 
 def write_syx_file(filename, messages, plaintext=False):
