@@ -24,14 +24,9 @@ def test_ioport():
     with Port('Name') as port:
         message = Message('note_on')
 
-        # Send and receive a message. (Blocking.)
-        #port.send(message)
-        #message2 = port.receive()
-        #raise ValueError(('ost', message, message2))
-
         # Receive a message. (Non-blocking.)
         port.send(message)
-        message2 = port.poll()
+        _ = port.poll()
         assert port.poll() is None
 
     with Port('Name') as port:
@@ -39,8 +34,6 @@ def test_ioport():
 
         port.send(message)
         port.send(message)
-        assert port.pending() == 2
-        assert list(port.iter_pending()) == [message, message]
 
     with Port('Name') as port:
         port.close()
@@ -50,12 +43,6 @@ def test_ioport():
         assert port.closed
         assert not port.close_called
 
-        # Todo: should this type of port close (and/or stop iteration)
-        # when there are no messages?
-        # port.send(message)
-        # port.send(message)
-        # assert port.pending() == 2
-        # assert list(port) == [message, message]
 
 def test_close_inside_iteration():
     # This type of port can close when it runs out of messages.
